﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        private DataTable dt;
        private ScatterChartAppearance sca1;
        private ScatterChartAppearance sca2;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            dt = new DataTable();
            dt.Columns.Add("Series1Label", typeof(string));
            dt.Columns.Add("Series1Value1", typeof(double));
            dt.Columns.Add("Series1Value2", typeof(double));
            dt.Columns.Add("Series2Label", typeof(string));
            dt.Columns.Add("Series2Value1", typeof(double));
            dt.Columns.Add("Series2Value2", typeof(double));

            dt.Rows.Add("Test A0", 10, 80, "Test B0", 50, 80);
            dt.Rows.Add("Test A1", 50, 30, "Test B1", 20, 30);
            dt.Rows.Add("Test A2", 60, 70, "Test B2", 90, 10);
            dt.Rows.Add("Test A3", 40, 30, "Test B3", 20, 70);
            dt.Rows.Add("Test A4", 10, 20, "Test B4", 25, 35);
            dt.Rows.Add("Test A5", 60, 40, "Test B5", 75, 55);


            AxisItem axisX = new AxisItem();
            axisX.DataType = AxisDataType.Numeric;
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.Extent = 30;
            axisX.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX.TimeAxisStyle.TimeAxisStyle = RulerGenre.Discrete;
            axisX.LineColor = Color.Blue;
            axisX.ScrollScale.Visible = true;
            area.Axes.Add(axisX);

            AxisItem axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.LineColor = Color.Blue;
            area.Axes.Add(axisY);


            XYSeries series1 = new XYSeries();
            series1.Label = "Series 1";
            series1.DataBind(dt, "Series1Value1", "Series1Value2", "Series1Label");
            series1.PEs.Add(new PaintElement(Color.Blue));

            XYSeries series2 = new XYSeries();
            series2.Label = "Series 2";
            series2.DataBind(dt, "Series2Value1", "Series2Value2", "Series2Label");
            series2.PEs.Add(new PaintElement(Color.Red));

            
            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ScatterChart;
            myColumnLayer.ChartArea = area;
            myColumnLayer.Series.Add(series1);
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            ultraChart1.CompositeChart.Series.Add(series1);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


            ChartLayerAppearance myColumnLayer2 = new ChartLayerAppearance();
            myColumnLayer2.ChartType = ChartType.ScatterChart;
            myColumnLayer2.ChartArea = area;
            myColumnLayer2.AxisX = axisX;
            myColumnLayer2.AxisY = axisY;
            myColumnLayer2.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer2);

            sca1 = new ScatterChartAppearance();
            sca1.ConnectWithLines = true;
            sca1.Icon = SymbolIcon.Circle;
            sca1.IconSize = SymbolIconSize.Large;
            myColumnLayer.ChartTypeAppearance = sca1;

            sca2 = new ScatterChartAppearance();
            sca2.ConnectWithLines = true;
            sca2.Icon = SymbolIcon.Triangle;
            sca2.IconSize = SymbolIconSize.Large;
            myColumnLayer2.ChartTypeAppearance = sca2;

            ultraComboEditor1.Items.Add(SymbolIcon.Circle);
            ultraComboEditor1.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor1.Items.Add(SymbolIcon.Plus);
            ultraComboEditor1.Items.Add(SymbolIcon.Square);
            ultraComboEditor1.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor1.Value = SymbolIcon.Circle;

            ultraComboEditor2.Items.Add(SymbolIcon.Circle);
            ultraComboEditor2.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor2.Items.Add(SymbolIcon.Plus);
            ultraComboEditor2.Items.Add(SymbolIcon.Square);
            ultraComboEditor2.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor2.Value = SymbolIcon.Triangle;
        }

        private void ultraButton3_Click(object sender, EventArgs e)
        {
            ultraChart1.SaveTo(@"..\\..\\Test.bmp", System.Drawing.Imaging.ImageFormat.Bmp);
        }

        private void ultraComboEditor1_ValueChanged(object sender, EventArgs e)
        {
            sca1.Icon = (SymbolIcon)ultraComboEditor1.Value;
        }

        private void ultraComboEditor2_ValueChanged(object sender, EventArgs e)
        {
            sca2.Icon = (SymbolIcon)ultraComboEditor2.Value;
        }

    }
}